@@ -13,15 +13,15 @@ def infer(img, model_pt):
 
     model.load_state_dict(torch.load(model_pt))
     if torch.cuda.is_available():
-        model = model.to(device)
+        model.to(device)
 
     input_image = Image.open(img)
     preprocess = transforms.Compose([transforms.ToTensor()])
     input_tensor = preprocess(input_image)
     input_batch = input_tensor.unsqueeze(0)
-    if torch.cuda.is_available():
-        input_batch = input_batch.cuda()
-    predicts = model(input_batch)
+    input_batch = input_batch.to(device)
+    with torch.no_grad():
+        predicts = model(input_batch)
     outs = decodePredicts(predicts, (1536, 512), 690)
     outs = outs.permute((0, 2, 3, 1).numpy().astype(np.uint8))
 
